# R script
# Usage: plot-rantom.r <results.csv> <output.csv>
# author: Xavier Devroey

require(sqldf)

# ------------------------------
# Main function definition
# ------------------------------

main <- function(){
	args <- commandArgs(trailingOnly = TRUE)
	
	# model,mutantorder,random,run,originalts,mutantts,failfirst,delta,epsilon,
	# estimatednbruns,effectivenbruns,failednbruns,equivdegree,
	# timeinms,counterexemples,messages
  
  randomdata <- read.csv(args[1], header = TRUE, sep = ',', quote = '', dec = ".")
  exactdata <- read.csv(sub('random.csv', 'exact.csv', args[1]), header = TRUE, sep = ',', quote = '', dec = ".")
  
  requestRandom <- "SELECT f1.random as random, f1.delta as delta, f1.epsilon as epsilon, 
      AVG(failednbruns  * 1.0)  AS recall, 
      AVG(timeinms * 1.0)/1000 AS avgtimeinsec,
      STDEV(timeinms * 1.0)/1000 AS stdevtimeinsec,
      (SELECT MAX(f2.timeinms)
        FROM randomdata f2 
        WHERE f2.mutantorder = 'equiv' 
          AND f2.random = f1.random 
          AND f2.delta = f1.delta 
          AND f2.epsilon = f1.epsilon)* 1.0 / 1000 AS maxtimeinsec
    FROM randomdata f1
    WHERE f1.mutantorder IN ('order1', 'order2', 'order5', 'order10')
    GROUP BY f1.random, f1.delta, f1.epsilon 
    ORDER BY f1.random, f1.delta, f1.epsilon"

	res <- sqldf(requestRandom)
	
  requestExact <- "SELECT 'NA' as random, -1 as delta, -1 as epsilon, 
      1.00  AS recall, 
      AVG(timeinsec * 1.0) AS avgtimeinsec,
      STDEV(timeinsec * 1.0) AS stdevtimeinsec,
      (SELECT MAX(f2.timeinsec)
        FROM exactdata f2 
        WHERE f2.mutantorder = 'equiv'
        	AND f2.mutant LIKE (f1.model||'.ts'))* 1.0 AS maxtimeinsec
    FROM exactdata f1
    WHERE f1.mutantorder IN ('order1', 'order2', 'order5', 'order10')"
  
  res <- rbind(res, sqldf(requestExact))
  
  write.csv(res, args[2]) 
}

# ------------------------------
# Program
# ------------------------------

main()