# R script
# 
# author: Xavier Devroey

require(base)

# ------------------------------
# Tables printing functions definition
# ------------------------------

formatTime <- function(value){
  v <- as.numeric(value)
  if(v < 0.01){
    return("$<$0.01")
  } else {
    return(formatC(v,digits=2,format="f"))
  }
}


printALE <- function(m, df){
  resALESM <- df[as.character(df$random) == "SM ALE",]
  resALEWM <- df[as.character(df$random) == "WM ALE",]
  cat("\\textbf{ALE} & & & 100\\% & ")
  cat(formatTime(mean(resALEWM$timeinsec)), " & ")
  cat(formatTime(sd(resALEWM$timeinsec)), " & ")
  cat("100\\% & ")
  cat(formatTime(mean(resALESM$timeinsec)), " & ")
  cat(formatTime(sd(resALESM$timeinsec)), " \\\\", "\n")
}


formatDeltaEpsilon <- function(value){
  v <- as.numeric(value)
  if(v < 0.01){
    return(formatC(v, digits = 0, format = "e"))
  } else {
    return(formatC(v,digits=2,format="f"))
  }
}

printBS <- function(m, df){
  allBSWM <- df[startsWith(as.character(df$random),"WM BS") & (as.character(df$mutantorder) != "equiv"),]
  allBSSM <- df[startsWith(as.character(df$random),"SM BS") & (as.character(df$mutantorder) != "equiv"),]
  cat("\\textbf{BS} ")
  for(i in 1:4){
    wmrandom <- paste0("WM BS",i)
    smrandom <- paste0("SM BS",i)
    resBSWM <- allBSWM[as.character(allBSWM$random) == wmrandom,]
    resBSSM <- allBSSM[as.character(allBSSM$random) == smrandom,]
    cat(" & ")
    cat(formatDeltaEpsilon(resBSWM$delta[1]), " & ")
    cat(formatDeltaEpsilon(resBSWM$epsilon[1]), " & ")
    cat(formatC(mean(resBSWM$killed) * 100, format = "d"), "\\% & ", sep = "")
    cat(formatTime(mean(resBSWM$timeinsec)), " & ")
    cat(formatTime(sd(resBSWM$timeinsec)), " & ")
    cat(formatC(mean(resBSWM$killed) * 100, format = "d"), "\\% & ", sep = "")
    cat(formatTime(mean(resBSSM$timeinsec)), " & ")
    cat(formatTime(sd(resBSSM$timeinsec)))
    cat("\\\\\n")
  }
}


printRS <- function(m, df){
  allRSWM <- df[startsWith(as.character(df$random),"WM RS") & (as.character(df$mutantorder) != "equiv"),]
  cat("\\textbf{RS} ")
  for(i in 1:4){
    wmrandom <- paste0("WM RS",i)
    resRSWM <- allRSWM[as.character(allRSWM$random) == wmrandom,]
    cat(" & ")
    cat(formatDeltaEpsilon(resRSWM$delta[1]), " & ")
    cat(formatDeltaEpsilon(resRSWM$epsilon[1]), " & ")
    cat(formatC(mean(resRSWM$killed) * 100, format = "d"), "\\% & ", sep = "")
    cat(formatTime(mean(resRSWM$timeinsec)), " & ")
    cat(formatTime(sd(resRSWM$timeinsec)))
    cat(" & N/A & N/A & N/A \\\\\n")
  }
}


printTable <- function(m, df, outputFile){
  cat("% ", m, "\n")
  cat("\\begin{scriptsize}", "\n")
  cat("\\begin{tabularx}{\\columnwidth}{lll|X|X|X|X|X|X}", "\n")
  cat(" & & & \\multicolumn{3}{c|}{\\textbf{Weak Mutation}} & \\multicolumn{3}{c}{\\textbf{Strong Mutation}}\\\\", "\n")
  cat(" & \\textbf{$\\delta$} & \\textbf{$\\epsilon$} & Recall & $\\overline{\\mathbf{time}}$ & $\\sigma$ & Recall & $\\overline{\\mathbf{time}}$ & $\\sigma$ \\\\ ", "\n")
  cat("\\hline", "\n")
  printALE(m, df)
  printBS(m, df)
  printRS(m, df)
  cat("\\end{tabularx}", "\n")
  cat("\\end{scriptsize}", "\n")
}


# ------------------------------
# Main function definition
# ------------------------------

main <- function(args){
  if(length(args) < 3){
    stop("Format: maketable.r <data.rds> <model> <output.tex>\n", call=FALSE)
  }
  df <- readRDS(args[1])
  outputFile <- args[2]
  m <- args[3]
  unlink(outputFile)
  sink(outputFile, append = TRUE, split = TRUE)
  printTable(m, df, outputFile)
  sink()
}

# ------------------------------
# Program
# ------------------------------

args <- commandArgs(trailingOnly = TRUE)
main(args)