#!/bin/bash -e

if [ "$1" == "" ] ; then
    echo "Usage : $0 <model>";
    echo "Exemple : $0 svm";
    exit 1;
fi;

scriptdir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

expdir=$scriptdir/../results/$1/
resdir=$scriptdir/../results/$1/
exactresults=$resdir/results-ale.csv
randomresults=$resdir/results-simulation.csv

randominputcsvheaders="originalts,mutantts,failfirst,delta,epsilon,estimatednbruns,effectivenbruns,failednbruns,equivdegree,timeinms,counterexemples,messages"

echo "Compiling random results for $1"

echo "model,mutantorder,random,run,${randominputcsvheaders/'counterexemples,'}" > $randomresults

for order in order1 order2 order5 order10 equiv; do
	for run in 11 12 13 21 22 23 31 32 33 41 42 43; do
		for random in random-weak biased-weak biased-strong; do
			csv=$expdir/$order-$random-run$run.csv
			nblines=$(($(cat $csv | wc -l) - 1))
			echo "Processing file $csv with $nblines lines"
			sed 1d $csv | while read line; do 
				if [ -z "$line" ];
				then
					echo "skipping empty line"
				else
					cleanline=$(echo $line | sed -e "s/{.*},//" | sed -e "s/\([^,]*\)[[:space:]]$/\"\1\"/")
					echo "$1,$order,$random,$run,$cleanline" >> $randomresults
				fi
			done
		done		
	done
done

exactinputcsvheaders="mutant,equivalent,timeinsec"

echo "Compiling exact results for $1"

echo "model,mutantorder,method,$exactinputcsvheaders" > $exactresults

for order in order1 order2 order5 order10 equiv; do
	for method in bwd-bfs bwd-dfs fwd-bfs fwd-dfs; do
		csv=$expdir/exact-$order-$method.csv
		nblines=$(($(cat $csv | wc -l)))
		echo "Processing file $csv with $nblines lines"
		while read line; do 
			if [ -z "$line" ];
			then
				echo "skipping empty line"
			else
				substr=$1/$order-tbk/
				line=${line/"$substr"/''}
				line=${line/'.txt'/''}
				line=${line//';'/','}
				echo "$1,$order,$method,$line" >> $exactresults
			fi
		done < $csv
	done
done