#!/bin/bash -e

if [ "$3" == "" ] ; then
    echo "Usage : $0 <model> <delta> <epsilon> <run-prefix>";
    echo "Exemple : $0 svm 0.00001 0.1 3";
    return;
fi;

dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

original=$dir/../models/$1/$1.ts
mutantsDir=$dir/../mutants/$1
jarfile=$dir/toolbox-mutation-equivalence-1.1.5-SNAPSHOT-jar-with-dependencies.jar
delta=$2
epsilon=$3
threads=4
tracesize=3000
logfile=$dir/../results/$1/random-equiv.log
runprefix=$4

echo "Random equivalence $1 (delta=$delta, epsilon=$epsilon)" > $logfile

for order in order1 order2 order5 order10 equiv; do
	echo "Random equivalence $1 for mutants $order"
	echo "Random equivalence $1 for mutants $order" >> $logfile

	for run in 1 2 3; do
		echo "Run $run"
		echo "Run $run" >> $logfile
		echo "Random Weak"
		echo "Random Weak" >> $logfile
		java -DentityExpansionLimit=0 -Xmx4096m  -jar $jarfile -d $delta -e $epsilon -threads $threads -s $tracesize  -ts  $original $mutantsDir/$order/ -o $dir/../results/$1/$order-random-weak-run$runprefix$run.csv > $dir/../results/$1/$order-random-weak-run$runprefix$run.log 2> $dir/../results/$1/$order-random-weak-run$runprefix$run.err
		echo "Biased Weak"
		echo "Biased Weak" >> $logfile
		java -DentityExpansionLimit=0 -Xmx4096m  -jar $jarfile -d $delta -e $epsilon -threads $threads -local -s $tracesize  -ts  $original $mutantsDir/$order/ -o $dir/../results/$1/$order-biased-weak-run$runprefix$run.csv > $dir/../results/$1/$order-biased-weak-run$runprefix$run.log 2> $dir/../results/$1/$order-biased-weak-run$runprefix$run.err
		echo "Biased Strong"
		echo "Biased Strong" >> $logfile
		java -DentityExpansionLimit=0 -Xmx4096m  -jar $jarfile -d $delta -e $epsilon -threads $threads -local -testcase -ts  $original $mutantsDir/$order/ -o $dir/../results/$1/$order-biased-strong-run$runprefix$run.csv > $dir/../results/$1/$order-biased-strong-run$runprefix$run.log 2> $dir/../results/$1/$order-biased-strong-run$runprefix$run.err
	done
done
